#
# Copyright (c), 2013, Flavio Castelli <fcastelli@suse.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

%if 0%{?suse_version} >= 1230
%bcond_without systemd
%else
%bcond_with systemd
%endif

Name:           docker-registry
Version:        0.6.1
Release:        9.1
Summary:        Docker registry
Group:          Development/Languages/Other
License:        MIT
URL:            https://github.com/dotcloud/docker-registry/
Source0:        docker-registry-%{version}.tar.bz2
Source1:        config.yml
Source2:        config-log
Source3:        run
Source4:        run-log
Source5:        docker-registry.service
Source6:        docker-registry.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires:       apache2
BuildRequires:  apache2
Requires:       python-Flask
Requires:       python-PyYAML
Requires:       python-blinker
Requires:       python-boto
Requires:       python-gevent
Requires:       python-glanceclient
Requires:       python-gunicorn
Requires:       python-keystoneclient
Requires:       python-redis
Requires:       python-requests
Requires:       python-rsa
Requires:       python-simplejson
%if %{with systemd}
BuildRequires:  systemd-devel
%{?systemd_requires}
%else
Requires:       runit
%endif
%if 0%{?suse_version} > 1020
BuildRequires:  fdupes
%endif

%description
Private instance of docker's registry.

%prep
%setup -q -n docker-registry

%build
%{__rm} -rf contrib/golang_impl

%install
%{__rm} -rf %{buildroot}

%{__mkdir_p} %{buildroot}/srv/www/vhosts/%{name}
%{__mkdir_p} %{buildroot}/var/lib/%{name}
%{__cp} -R * %{buildroot}/srv/www/vhosts/%{name}/
%{__install} -m644 %{SOURCE1} %{buildroot}/srv/www/vhosts/%{name}/config.yml
%{__mkdir_p} %{buildroot}%{_sysconfdir}/apache2/vhosts.d
%{__install} -m644 %{SOURCE6} %{buildroot}%{_sysconfdir}/apache2/vhosts.d

%if %{with systemd}
%{__install} -D -m 0644 %SOURCE5 %{buildroot}%{_unitdir}/%{name}.service
%else
%{__mkdir_p} %{buildroot}%{_sysconfdir}/sv/%{name}/log/
%{__install} -m755 %{SOURCE3} %{buildroot}%{_sysconfdir}/sv/%{name}/run
%{__install} -m644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sv/%{name}/log/config
%{__install} -m755 %{SOURCE4} %{buildroot}%{_sysconfdir}/sv/%{name}/log/run
%endif

%if 0%{?suse_version} > 1020
%fdupes -s %{buildroot}/srv/www/vhosts/%{name}
%endif

%clean
%{__rm} -rf %{buildroot}

%if %{with systemd}
%preun
%service_del_preun docker-registry.service

%postun
%service_del_postun docker-registry.service
%endif

%pre
/usr/sbin/groupadd -r %{name} &>/dev/null || :
/usr/sbin/useradd -g %{name} -s /bin/false -r -c "Docker Registry" -d %{_var}/lib/%{name} %{name} &>/dev/null || :
%if %{with systemd}
%service_add_pre docker-registry.service
%endif

%post
/usr/sbin/a2enmod proxy
/usr/sbin/a2enmod proxy_http
%if %{with systemd}
%service_add_post docker-registry.service
%endif

%files
%defattr(-,root,root,-)
%attr(-,root,www) /srv/www/vhosts/
%attr(-,root,www) /srv/www/vhosts/%{name}
%attr(-,docker-registry,www) /var/lib/%{name}
%config %{_sysconfdir}/apache2/vhosts.d/docker-registry.conf

%if %{with systemd}
%{_unitdir}/%{name}.service
%else
%config %{_sysconfdir}/sv/%{name}/log/config
%{_sysconfdir}/sv/
%{_sysconfdir}/sv/%{name}/*
%endif
%changelog
* Tue Mar  4 2014 fcastelli@suse.com
- spec file cleanup: check for systemd support with style.
* Tue Mar  4 2014 fcastelli@suse.com
- Ensure systemd starts docker-registry using 'prod' environment.
* Mon Mar  3 2014 fcastelli@suse.com
- Use systemd on newer SUSE systems, runit on older versions.
- Ship systemd configuration.
- Ship apache configuration.
- Require apache2.
* Tue Jan 14 2014 fcastelli@suse.com
- Got rid of the golang implementation
- Fixed some warning messages or rpmlint
* Wed Dec 18 2013 fcastelli@suse.com
- Run the service as the docker-registry user.
* Wed Dec 18 2013 fcastelli@suse.com
- small improvements to the run script
- create docker-registry user
* Tue Dec 17 2013 fcastelli@suse.com
- Cleanup of the spec file:
  * fixed wrong url
  * added config-log file
  * removed logrotate dependency
  * install docker-registry under /srv/www/vhosts/docker-registry
* Tue Dec 17 2013 fcastelli@suse.com
- packaged version 0.6.1
- Switched back to the offical docker registry implementation (the one based
  on python).
* Tue Jul 30 2013 fcastelli@suse.com
- add & handle configuration file
* Tue Jul 30 2013 fcastelli@suse.com
- created initial package.
